@@ -8,6 +8,18 @@
  * @flow
  */
 
+export type FunctionReturning<+T> = (...args: $ReadOnlyArray<mixed>) => T;
+
+export type EmptyFunctionType = {
+  (...args: $ReadOnlyArray<mixed>): void,
+  thatReturns: <T>(x: T) => FunctionReturning<T>,
+  thatReturnsFalse: FunctionReturning<false>,
+  thatReturnsTrue: FunctionReturning<true>,
+  thatReturnsNull: FunctionReturning<null>,
+  thatReturnsThis: FunctionReturning<mixed>,
+  thatReturnsArgument: <T>(x: T) => T,
+};
+
 function makeEmptyFunction<T>(arg: T): (...args: Array<any>) => T {
   return function() {
     return arg;
@@ -19,7 +31,7 @@ function makeEmptyFunction<T>(arg: T): (...args: Array<any>) => T {
  * primarily useful idiomatically for overridable function endpoints which
  * always need to be callable, since JS lacks a null-call idiom ala Cocoa.
  */
-const emptyFunction: (...args: Array<any>) => void = function() {};
+const emptyFunction = function() {};
 
 emptyFunction.thatReturns = makeEmptyFunction;
 emptyFunction.thatReturnsFalse = makeEmptyFunction(false);
@@ -28,4 +40,4 @@ emptyFunction.thatReturnsNull = makeEmptyFunction(null);
 emptyFunction.thatReturnsThis = function() { return this; };
 emptyFunction.thatReturnsArgument = function(arg) { return arg; };
 
-module.exports = emptyFunction;
+module.exports = (emptyFunction: EmptyFunctionType);
